import { html } from 'lit-html';
import { Position } from './multiselect';
const meta = {
    title: 'Multiselect',
    component: 'rapid-multiselect',
};
export default meta;
const notificationSeverities = [
    {
        value: 'Information',
        label: 'Information',
        labelStyle: 'color: var(--info-color)',
    },
    {
        value: 'Warning',
        label: 'Warning',
        labelStyle: 'color: var(--warning-color)',
    },
    {
        value: 'Serious',
        label: 'Serious',
        labelStyle: 'color: var(--serious-notify-color)',
    },
    {
        value: 'Critical',
        label: 'Critical',
        labelStyle: 'color: var(--error-color)',
    },
];
const countriesList = [
    'Afghanistan',
    'Aland Islands',
    'Albania',
    'Algeria',
    'American Samoa',
    'Andorra',
    'Angola',
    'Anguilla',
    'Antarctica',
    'Antigua and Barbuda',
    'Argentina',
    'Armenia',
    'Aruba',
    'Australia',
    'Austria',
    'Azerbaijan',
    'Bahamas',
    'Bahrain',
    'Bangladesh',
    'Barbados',
    'Belarus',
    'Belgium',
    'Belize',
    'Benin',
    'Bermuda',
    'Bhutan',
    'Bolivia',
    'Bonaire, Sint Eustatius and Saba',
    'Bosnia and Herzegovina',
    'Botswana',
    'Bouvet Island',
    'Brazil',
    'British Indian Ocean Territory',
    'Brunei Darussalam',
    'Bulgaria',
    'Burkina Faso',
    'Burundi',
    'Cambodia',
    'Cameroon',
    'Canada',
    'Cape Verde',
    'Cayman Islands',
    'Central African Republic',
    'Chad',
];
const disabledCountriesExample = [
    {
        value: 'AFG',
        label: 'Afghanistan',
        disabled: false,
    },
    {
        value: 'ALA',
        label: 'Aland Islands',
    },
    {
        value: 'ALB',
        label: 'Albania',
        disabled: false,
    },
    {
        value: 'ALG',
        label: 'Algeria',
        disabled: false,
    },
    {
        value: 'AND',
        label: 'Andorra',
        disabled: true,
    },
    {
        value: 'ARG',
        label: 'Argentina',
        disabled: true,
    },
    {
        value: 'ARM',
        label: 'Armenia',
        disabled: false,
    },
    {
        value: 'AUS',
        label: 'Australia',
        disabled: false,
    },
    {
        value: 'AUT',
        label: 'Austria',
        disabled: true,
    },
    {
        value: 'AZE',
        label: 'Azerbaijan',
        disabled: false,
    },
];
const makeStory = (args) => ({
    render: ({ name, text, countries, search, disabled, creatable, autoPosition, position, filterByContains, }) => html `
    <div style="min-height: 400px;">
      <style>
        rapid-multiselect::part(option-label)::after {
          background-color: var(--accent-fill-rest);
          border-radius: calc((var(--control-corner-radius) + 1) * 1px);
          color: #fff;
          content: attr(data-option-label-text);
          font-size: var(--type-ramp-minus-2-font-size);
          padding: calc((var(--design-unit) - 2) * 1px) calc(var(--design-unit) * 2px);
          position: absolute;
          right: 0;
          transform: translateX(-6px);
          white-space: nowrap;
        }
      </style>
      <rapid-multiselect
        name="${name}"
        .options="${countries}"
        auto-position="${autoPosition}"
        position="${position}"
        search="${search}"
        disabled="${disabled}"
        creatable="${creatable}"
        filter-by-contains="${filterByContains}"
      >
        <label slot="label">${text}</label>
      </rapid-multiselect>
    </div>
  `,
    args: Object.assign({ name: 'Countries', search: true, disabled: false, countries: countriesList, autoPosition: true, position: Position.BELOW, creatable: false, filterByContains: false }, args),
});
export const Primary = makeStory({ text: 'MultiSelect' });
export const Disabled = makeStory({ text: 'Disabled', disabled: true });
export const DisabledOptions = makeStory({
    text: 'Disabled Options',
    countries: disabledCountriesExample,
});
export const OptionsWithCustomStyling = makeStory({
    text: 'Options with custom styling',
    countries: disabledCountriesExample.map((opt) => (Object.assign(Object.assign({}, (typeof opt === 'string' ? { value: opt, label: opt } : opt)), { optionLabelText: 'bubble' }))),
});
export const AutoPosition = makeStory({
    text: 'Disabled Auto Position',
    countries: disabledCountriesExample,
    autoPosition: false,
    position: Position.ABOVE,
});
export const Creatable = makeStory({
    text: 'Creatable',
    countries: disabledCountriesExample,
    autoPosition: false,
    position: Position.ABOVE,
    creatable: true,
});
export const ContainsSearch = makeStory({
    text: 'Search By Contains',
    filterByContains: true,
});
export const labelStyle = {
    args: {
        disabled: false,
        autoPosition: true,
        position: Position.BELOW,
        search: false,
        all: false,
    },
    render: ({ autoPosition, position, search, all }) => html `
    <div style="min-height: 300px;">
      <rapid-multiselect
        name="${name}"
        .options="${notificationSeverities}"
        auto-position="${autoPosition}"
        position="${position}"
        search="${search}"
        all="${all}"
      ></rapid-multiselect>
    </div>
  `,
};
